@@ -235,20 +235,14 @@ pub mod govern {
 /// Errors.
 #[error]
 pub enum ErrorCode {
-    #[msg("Activator is not whitelisted.")]
-    ActivatorNotWhitelisted,
     #[msg("Invalid vote side.")]
     InvalidVoteSide,
-    #[msg("Invalid proposal state.")]
-    InvalidProposalState,
-    #[msg("Invalid transaction account.")]
-    InvalidTransactionAccount,
     #[msg("The owner of the smart wallet doesn't match with current.")]
-    SmartWalletNotFound,
+    GovernorNotFound,
     #[msg("The proposal cannot be activated since it has not yet passed the voting delay.")]
     VotingDelayNotMet,
     #[msg("Only drafts can be canceled.")]
     ProposalNotDraft,
-    #[msg("The proposal must be activated.")]
-    ProposalNotActivated,
+    #[msg("The proposal must be active.")]
+    ProposalNotActive,
 }
