@@ -61,9 +61,8 @@ pub struct Proposal {
     /// Current number of votes for abstaining for this proposal
     pub abstain_votes: u64,
 
-    /// Flag marking whether the proposal has been canceled
-    pub canceled: bool,
-
+    /// The timestamp when the proposal was canceled.
+    pub canceled_at: i64,
     /// The timestamp when the proposal was created.
     pub created_at: i64,
     /// The timestamp in which the proposal was activated.
